<?xml version="1.0" encoding="UTF-8"?>
<!--
Licensed Materials - Property of IBM
5724-L01
(C) Copyright IBM Corporation 2005, 2010. All Rights Reserved.
US Government Users Restricted Rights- Use, duplication or disclosure
restricted by GSA ADP Schedule Contract with IBM Corp.
-->
<xsl:transform xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
               xmlns:xalan="http://xml.apache.org/xslt"
               xmlns:staff="http://www.ibm.com/schemas/workflow/wswf/plugins/staff"
               xmlns:ssys="http://www.ibm.com/schemas/workflow/wswf/plugins/staff/system"
               version="1.0">

  <xsl:output standalone="no"
              encoding="UTF-8"
              omit-xml-declaration="no"
              media-type="text/xml"
              method="xml"
              indent="yes"
              version="1.0"/>

  <xsl:strip-space elements="*"/>



<!-- Begin global variables -->
  <xsl:variable name="Threshold">1000000</xsl:variable>
<!-- End global variables -->



<!-- Begin global dispatching -->
  <xsl:template match="/staff:verb">
    <xsl:variable name="verb1">
      <xsl:value-of select="staff:name/text()"/>
    </xsl:variable>

    <xsl:variable name="verb">
      <xsl:value-of select="normalize-space($verb1)" />
    </xsl:variable>    

    <xsl:choose>
      <xsl:when test="$verb='Users'">
        <xsl:call-template name="Users"/>
      </xsl:when>
      <xsl:when test="$verb='Users by user ID'">
        <xsl:call-template name="UsersByUserID"/>
      </xsl:when>
      <xsl:when test="$verb='Users by user ID without Named Users'">
        <xsl:call-template name="UsersByUserIDWithoutNamedUsers"/>
      </xsl:when>
      <xsl:when test="$verb='Group Members'">
        <xsl:message terminate="no">ERROR: Verb 'Group Members' is not supported by the SystemStaffResolutionPlugin</xsl:message>
      </xsl:when>
      <xsl:when test="$verb='Role Members'">
        <xsl:message terminate="no">ERROR: Verb 'Role Members' is not supported by the SystemStaffResolutionPlugin</xsl:message>
      </xsl:when>
      <xsl:when test="$verb='Department Members'">
        <xsl:message terminate="no">ERROR: Verb 'Department Members' is not supported by the SystemStaffResolutionPlugin</xsl:message>
      </xsl:when>
      <xsl:when test="$verb='Manager of Employee'">
        <xsl:message terminate="no">ERROR: Verb 'Manager of Employee' is not supported by the SystemStaffResolutionPlugin</xsl:message>
      </xsl:when>
      <xsl:when test="$verb='Manager of Employee by user ID'">
        <xsl:message terminate="no">ERROR: Verb 'Manager of Employee by user ID' is not supported by the SystemStaffResolutionPlugin</xsl:message>
      </xsl:when>
      <xsl:when test="$verb='Person Search'">
        <xsl:message terminate="no">ERROR: Verb 'Person Search' is not supported by the SystemStaffResolutionPlugin</xsl:message>
      </xsl:when>
      <xsl:when test="$verb='Group Search'">
        <xsl:message terminate="no">ERROR: Verb 'Group Search' is not supported by the SystemStaffResolutionPlugin</xsl:message>
      </xsl:when>
      <xsl:when test="$verb='Native Query'">
        <xsl:message terminate="no">ERROR: Verb 'Native Query' is not supported by the SystemStaffResolutionPlugin</xsl:message>
      </xsl:when>
      <xsl:when test="$verb='Everybody'">
        <xsl:call-template name="Everybody"/>
      </xsl:when>
      <xsl:when test="$verb='Nobody'">
        <xsl:call-template name="Nobody"/>
      </xsl:when>
      <xsl:when test="$verb='Group'">
        <xsl:call-template name="Group"/>
      </xsl:when>
      <xsl:when test="$verb='Groups'">
        <xsl:call-template name="Groups"/>
      </xsl:when>
      <xsl:when test="$verb='Users by user ID and groups'">
        <xsl:call-template name="UsersByUserIDAndGroups"/>
      </xsl:when>
      <xsl:otherwise>
        <xsl:message terminate="no">ERROR: Unsupported verb: '<xsl:value-of select="$verb"/>'.</xsl:message>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
<!-- End global dispatching -->



<!-- Begin template Users and children -->
  <xsl:template name="Users">
    <xsl:variable name="Name0">
      <xsl:value-of select="staff:parameter[@id='Name']"/>
    </xsl:variable>
    <xsl:variable name="Name1">
      <xsl:value-of select="staff:parameter[@id='AlternativeName1']"/>
    </xsl:variable>
    <xsl:variable name="Name2">
      <xsl:value-of select="staff:parameter[@id='AlternativeName2']"/>
    </xsl:variable>
    <xsl:variable name="Name3">
      <xsl:value-of select="staff:parameter[@id='AlternativeName3']"/>
    </xsl:variable>
    <xsl:variable name="Name4">
      <xsl:value-of select="staff:parameter[@id='AlternativeName4']"/>
    </xsl:variable>
    <xsl:variable name="Name5">
      <xsl:value-of select="staff:parameter[@id='AlternativeName5']"/>
    </xsl:variable>

    <ssys:staffQueries>
      <xsl:attribute name="threshold">
        <xsl:value-of select="$Threshold"/>
      </xsl:attribute>
      <xsl:call-template name="GetUser">
        <xsl:with-param name="username">
          <xsl:value-of select="$Name0"/>
        </xsl:with-param>
      </xsl:call-template>
      <xsl:if test="$Name1!=''">
        <xsl:call-template name="GetUser">
          <xsl:with-param name="username">
            <xsl:value-of select="$Name1"/>
          </xsl:with-param>
        </xsl:call-template>
      </xsl:if>
      <xsl:if test="$Name2!=''">
        <xsl:call-template name="GetUser">
          <xsl:with-param name="username">
            <xsl:value-of select="$Name2"/>
          </xsl:with-param>
        </xsl:call-template>
      </xsl:if>
      <xsl:if test="$Name3!=''">
        <xsl:call-template name="GetUser">
          <xsl:with-param name="username">
            <xsl:value-of select="$Name3"/>
          </xsl:with-param>
        </xsl:call-template>
      </xsl:if>
      <xsl:if test="$Name4!=''">
        <xsl:call-template name="GetUser">
          <xsl:with-param name="username">
            <xsl:value-of select="$Name4"/>
          </xsl:with-param>
        </xsl:call-template>
      </xsl:if>
      <xsl:if test="$Name5!=''">
        <xsl:call-template name="GetUser">
          <xsl:with-param name="username">
            <xsl:value-of select="$Name5"/>
          </xsl:with-param>
        </xsl:call-template>
      </xsl:if>
    </ssys:staffQueries>
  </xsl:template>
    

  <xsl:template name="GetUser">
    <xsl:param name="username">default</xsl:param>
    <ssys:userID>
      <xsl:attribute name="name">
        <xsl:value-of select="$username"/>
      </xsl:attribute>
    </ssys:userID>
  </xsl:template>
<!-- End template Users and children -->



<!-- Begin template UsersByUserID -->
  <xsl:template name="UsersByUserID">
    <xsl:variable name="Name0">
      <xsl:value-of select="staff:parameter[@id='UserID']"/>
    </xsl:variable>
    <xsl:variable name="Name1">
      <xsl:value-of select="staff:parameter[@id='AlternativeID1']"/>
    </xsl:variable>
    <xsl:variable name="Name2">
      <xsl:value-of select="staff:parameter[@id='AlternativeID2']"/>
    </xsl:variable>
    <xsl:variable name="Name3">
      <xsl:value-of select="staff:parameter[@id='AlternativeID3']"/>
    </xsl:variable>
    <xsl:variable name="Name4">
      <xsl:value-of select="staff:parameter[@id='AlternativeID4']"/>
    </xsl:variable>
    <xsl:variable name="Name5">
      <xsl:value-of select="staff:parameter[@id='AlternativeID5']"/>
    </xsl:variable>

    <ssys:staffQueries>
      <xsl:attribute name="threshold">
        <xsl:value-of select="$Threshold"/>
      </xsl:attribute>
      <xsl:call-template name="GetUser">
        <xsl:with-param name="username">
          <xsl:value-of select="$Name0"/>
        </xsl:with-param>
      </xsl:call-template>
      <xsl:if test="$Name1!=''">
        <xsl:call-template name="GetUser">
          <xsl:with-param name="username">
            <xsl:value-of select="$Name1"/>
          </xsl:with-param>
        </xsl:call-template>
      </xsl:if>
      <xsl:if test="$Name2!=''">
        <xsl:call-template name="GetUser">
          <xsl:with-param name="username">
            <xsl:value-of select="$Name2"/>
          </xsl:with-param>
        </xsl:call-template>
      </xsl:if>
      <xsl:if test="$Name3!=''">
        <xsl:call-template name="GetUser">
          <xsl:with-param name="username">
            <xsl:value-of select="$Name3"/>
          </xsl:with-param>
        </xsl:call-template>
      </xsl:if>
      <xsl:if test="$Name4!=''">
        <xsl:call-template name="GetUser">
          <xsl:with-param name="username">
            <xsl:value-of select="$Name4"/>
          </xsl:with-param>
        </xsl:call-template>
      </xsl:if>
      <xsl:if test="$Name5!=''">
        <xsl:call-template name="GetUser">
          <xsl:with-param name="username">
            <xsl:value-of select="$Name5"/>
          </xsl:with-param>
        </xsl:call-template>
      </xsl:if>
    </ssys:staffQueries>
  </xsl:template>
<!-- End template UsersByUserID -->


<!-- Begin template UsersByUserIDWithoutNamedUsers -->
  <xsl:template name="UsersByUserIDWithoutNamedUsers">
    <xsl:variable name="Name0">
      <xsl:value-of select="staff:parameter[@id='UserID']"/>
    </xsl:variable>
    <xsl:variable name="Name1">
      <xsl:value-of select="staff:parameter[@id='AlternativeID1']"/>
    </xsl:variable>
    <xsl:variable name="Name2">
      <xsl:value-of select="staff:parameter[@id='AlternativeID2']"/>
    </xsl:variable>
    <xsl:variable name="Name3">
      <xsl:value-of select="staff:parameter[@id='AlternativeID3']"/>
    </xsl:variable>
    <xsl:variable name="Name4">
      <xsl:value-of select="staff:parameter[@id='AlternativeID4']"/>
    </xsl:variable>
    <xsl:variable name="Name5">
      <xsl:value-of select="staff:parameter[@id='AlternativeID5']"/>
    </xsl:variable>
    <ssys:staffQueries>
      <xsl:call-template name="GetUser">
        <xsl:with-param name="username">
          <xsl:value-of select="$Name0"/>
        </xsl:with-param>
      </xsl:call-template>
      <xsl:if test="$Name1!=''">
        <xsl:call-template name="GetUser">
          <xsl:with-param name="username">
            <xsl:value-of select="$Name1"/>
          </xsl:with-param>
        </xsl:call-template>
      </xsl:if>
      <xsl:if test="$Name2!=''">
        <xsl:call-template name="GetUser">
          <xsl:with-param name="username">
            <xsl:value-of select="$Name2"/>
          </xsl:with-param>
        </xsl:call-template>
      </xsl:if>
      <xsl:if test="$Name3!=''">
        <xsl:call-template name="GetUser">
          <xsl:with-param name="username">
            <xsl:value-of select="$Name3"/>
          </xsl:with-param>
        </xsl:call-template>
      </xsl:if>
      <xsl:if test="$Name4!=''">
        <xsl:call-template name="GetUser">
          <xsl:with-param name="username">
            <xsl:value-of select="$Name4"/>
          </xsl:with-param>
        </xsl:call-template>
      </xsl:if>
      <xsl:if test="$Name5!=''">
        <xsl:call-template name="GetUser">
          <xsl:with-param name="username">
            <xsl:value-of select="$Name5"/>
          </xsl:with-param>
        </xsl:call-template>
      </xsl:if>

      <ssys:remove>
        <xsl:attribute name="value"><xsl:value-of select="staff:parameter[@id='NamedUsers']"/></xsl:attribute>
      </ssys:remove>            
       
    </ssys:staffQueries>
  </xsl:template>
<!-- End template UsersByUserIDWithoutNamedUsers -->



<!-- Begin template Group -->
  <xsl:template name="Group">
    <xsl:variable name="GroupID">
      <xsl:value-of select="staff:parameter[@id='GroupID']"/>
    </xsl:variable>

    <ssys:staffQueries>
      <xsl:call-template name="GetGroup">
        <xsl:with-param name="groupname">
          <xsl:value-of select="$GroupID"/>
        </xsl:with-param>
      </xsl:call-template>
    </ssys:staffQueries>
  </xsl:template>

  <xsl:template name="GetGroup">
    <xsl:param name="groupname">default</xsl:param>
    <ssys:groupID>
      <xsl:attribute name="name">
        <xsl:value-of select="$groupname"/>
      </xsl:attribute>
    </ssys:groupID>
  </xsl:template>
<!-- End template Group -->



<!-- Begin template Groups -->
  <xsl:template name="Groups">
    <xsl:variable name="GroupID0">
      <xsl:value-of select="staff:parameter[@id='GroupID']"/>
    </xsl:variable>
    <xsl:variable name="GroupID1">
      <xsl:value-of select="staff:parameter[@id='AlternativeGroupID1']"/>
    </xsl:variable>
    <xsl:variable name="GroupID2">
      <xsl:value-of select="staff:parameter[@id='AlternativeGroupID2']"/>
    </xsl:variable>
    <xsl:variable name="GroupID3">
      <xsl:value-of select="staff:parameter[@id='AlternativeGroupID3']"/>
    </xsl:variable>
    <xsl:variable name="GroupID4">
      <xsl:value-of select="staff:parameter[@id='AlternativeGroupID4']"/>
    </xsl:variable>
    <xsl:variable name="GroupID5">
      <xsl:value-of select="staff:parameter[@id='AlternativeGroupID5']"/>
    </xsl:variable>

    <ssys:staffQueries>
      <xsl:call-template name="GetGroup">
        <xsl:with-param name="groupname">
          <xsl:value-of select="$GroupID0"/>
        </xsl:with-param>
      </xsl:call-template>
      <xsl:if test="$GroupID1!=''">
        <xsl:call-template name="GetGroup">
          <xsl:with-param name="groupname">
            <xsl:value-of select="$GroupID1"/>
          </xsl:with-param>
        </xsl:call-template>
      </xsl:if>
      <xsl:if test="$GroupID2!=''">
        <xsl:call-template name="GetGroup">
          <xsl:with-param name="groupname">
            <xsl:value-of select="$GroupID2"/>
          </xsl:with-param>
        </xsl:call-template>
      </xsl:if>
      <xsl:if test="$GroupID3!=''">
        <xsl:call-template name="GetGroup">
          <xsl:with-param name="groupname">
            <xsl:value-of select="$GroupID3"/>
          </xsl:with-param>
        </xsl:call-template>
      </xsl:if>
      <xsl:if test="$GroupID4!=''">
        <xsl:call-template name="GetGroup">
          <xsl:with-param name="groupname">
            <xsl:value-of select="$GroupID4"/>
          </xsl:with-param>
        </xsl:call-template>
      </xsl:if>
      <xsl:if test="$GroupID5!=''">
        <xsl:call-template name="GetGroup">
          <xsl:with-param name="groupname">
            <xsl:value-of select="$GroupID5"/>
          </xsl:with-param>
        </xsl:call-template>
      </xsl:if>
    </ssys:staffQueries>
  </xsl:template>
<!-- End template Groups -->



<!-- Begin template UsersByUserIDAndGroups -->
  <xsl:template name="UsersByUserIDAndGroups">
    <xsl:variable name="Name0">
      <xsl:value-of select="staff:parameter[@id='UserID']"/>
    </xsl:variable>
    <xsl:variable name="Name1">
      <xsl:value-of select="staff:parameter[@id='AlternativeUserID1']"/>
    </xsl:variable>
    <xsl:variable name="Name2">
      <xsl:value-of select="staff:parameter[@id='AlternativeUserID2']"/>
    </xsl:variable>
    <xsl:variable name="Name3">
      <xsl:value-of select="staff:parameter[@id='AlternativeUserID3']"/>
    </xsl:variable>
    <xsl:variable name="Name4">
      <xsl:value-of select="staff:parameter[@id='AlternativeUserID4']"/>
    </xsl:variable>
    <xsl:variable name="Name5">
      <xsl:value-of select="staff:parameter[@id='AlternativeUserID5']"/>
    </xsl:variable>
    <xsl:variable name="GroupID0">
      <xsl:value-of select="staff:parameter[@id='GroupID']"/>
    </xsl:variable>
    <xsl:variable name="GroupID1">
      <xsl:value-of select="staff:parameter[@id='AlternativeGroupID1']"/>
    </xsl:variable>
    <xsl:variable name="GroupID2">
      <xsl:value-of select="staff:parameter[@id='AlternativeGroupID2']"/>
    </xsl:variable>
    <xsl:variable name="GroupID3">
      <xsl:value-of select="staff:parameter[@id='AlternativeGroupID3']"/>
    </xsl:variable>
    <xsl:variable name="GroupID4">
      <xsl:value-of select="staff:parameter[@id='AlternativeGroupID4']"/>
    </xsl:variable>
    <xsl:variable name="GroupID5">
      <xsl:value-of select="staff:parameter[@id='AlternativeGroupID5']"/>
    </xsl:variable>

    <ssys:staffQueries>
      <xsl:attribute name="threshold">
        <xsl:value-of select="$Threshold"/>
      </xsl:attribute>
      <xsl:call-template name="GetUser">
        <xsl:with-param name="username">
          <xsl:value-of select="$Name0"/>
        </xsl:with-param>
      </xsl:call-template>
      <xsl:if test="$Name1!=''">
        <xsl:call-template name="GetUser">
          <xsl:with-param name="username">
            <xsl:value-of select="$Name1"/>
          </xsl:with-param>
        </xsl:call-template>
      </xsl:if>
      <xsl:if test="$Name2!=''">
        <xsl:call-template name="GetUser">
          <xsl:with-param name="username">
            <xsl:value-of select="$Name2"/>
          </xsl:with-param>
        </xsl:call-template>
      </xsl:if>
      <xsl:if test="$Name3!=''">
        <xsl:call-template name="GetUser">
          <xsl:with-param name="username">
            <xsl:value-of select="$Name3"/>
          </xsl:with-param>
        </xsl:call-template>
      </xsl:if>
      <xsl:if test="$Name4!=''">
        <xsl:call-template name="GetUser">
          <xsl:with-param name="username">
            <xsl:value-of select="$Name4"/>
          </xsl:with-param>
        </xsl:call-template>
      </xsl:if>
      <xsl:if test="$Name5!=''">
        <xsl:call-template name="GetUser">
          <xsl:with-param name="username">
            <xsl:value-of select="$Name5"/>
          </xsl:with-param>
        </xsl:call-template>
      </xsl:if>
      <xsl:call-template name="GetGroup">
        <xsl:with-param name="groupname">
          <xsl:value-of select="$GroupID0"/>
        </xsl:with-param>
      </xsl:call-template>
      <xsl:if test="$GroupID1!=''">
        <xsl:call-template name="GetGroup">
          <xsl:with-param name="groupname">
            <xsl:value-of select="$GroupID1"/>
          </xsl:with-param>
        </xsl:call-template>
      </xsl:if>
      <xsl:if test="$GroupID2!=''">
        <xsl:call-template name="GetGroup">
          <xsl:with-param name="groupname">
            <xsl:value-of select="$GroupID2"/>
          </xsl:with-param>
        </xsl:call-template>
      </xsl:if>
      <xsl:if test="$GroupID3!=''">
        <xsl:call-template name="GetGroup">
          <xsl:with-param name="groupname">
            <xsl:value-of select="$GroupID3"/>
          </xsl:with-param>
        </xsl:call-template>
      </xsl:if>
      <xsl:if test="$GroupID4!=''">
        <xsl:call-template name="GetGroup">
          <xsl:with-param name="groupname">
            <xsl:value-of select="$GroupID4"/>
          </xsl:with-param>
        </xsl:call-template>
      </xsl:if>
      <xsl:if test="$GroupID5!=''">
        <xsl:call-template name="GetGroup">
          <xsl:with-param name="groupname">
            <xsl:value-of select="$GroupID5"/>
          </xsl:with-param>
        </xsl:call-template>
      </xsl:if>
    </ssys:staffQueries>
  </xsl:template>
<!-- End template UsersByUserIDAndGroups -->


  
<!-- Begin template Everybody -->
  <xsl:template name="Everybody">
    <ssys:staffQueries>
      <ssys:everybody/>
    </ssys:staffQueries>
  </xsl:template>
<!-- End template Everybody -->



<!-- Begin template Nobody -->
  <xsl:template name="Nobody">
    <ssys:staffQueries>
      <ssys:nobody/>
    </ssys:staffQueries>
  </xsl:template>
<!-- End template Nobody -->
</xsl:transform>