#BEGIN COPYRIGHT
#*************************************************************************
#
# Licensed Materials - Property of IBM
# 5725-C94
# (C) Copyright IBM Corporation 2006, 2012. All Rights Reserved.
# US Government Users Restricted Rights- Use, duplication or disclosure
# restricted by GSA ADP Schedule Contract with IBM Corp.
#
#*************************************************************************
#END COPYRIGHT

import os.path, sys

from java.lang import System
from javax.management import ObjectName

execfile(os.path.join(System.getProperty("was.install.root"), "ProcessChoreographer/config/bpclib.py"))
__file__ = "deleteInvalidProcessTemplate.py"

#*******************************************************************************************************
# print usage and error message, if any
#*******************************************************************************************************
def usage(errmsg = None):
  if errmsg:
    print
    print "ERROR: " + errmsg
  #endif
  print
  print "Usage: wsadmin -f " + __file__
  print "       ( ( [-node <nodeName>] -server <serverName> ) | ( -cluster <clusterName> ) )"
  print "       -templateName <templateName> -validFromUTC <timestamp>"
  print
  print "Delete process template without corresponding enterprise application"
  print "on server <serverName> on node <nodeName> or of cluster <clusterName>. "
  print
  print "<timestamp> format must be <yyyy>-<MM>-<dd>T<HH>:<mm>:<ss>."
  print "Example timestamp: 2006-11-04T21:57:22"
  print
  print "The default values for the optional parameters are:"
  print "  node:               <local node> (" + localNode + ")"
#enddef

#*******************************************************************************************************
# main
#*******************************************************************************************************
localNode = java.lang.System.getProperty ( "local.node" )

if wsadmin.getConnectionStatus() != WsAdmin.CONNECTED:
  usage(__file__ + " must run in connected mode, cannot use the '-conntype NONE' option.")
  sys.exit(1)
#endif

argerr = ""
templateName = ""
validFrom = ""
nodeName = localNode
clusterName = None
serverName  = None

argc = len(sys.argv)

i = 0
while ( i < argc ):
  arg = sys.argv[i]
  if (arg == "-node"):
    i = i+1;
    if (i < argc):
      nodeName = sys.argv[i]
    else:
      argerr = "Missing argument for '-node' parameter"
    #endElse
  elif (arg == "-server"):
    i = i+1;
    if (i < argc):
      serverName = sys.argv[i]
    else:
       argerr = "Missing argument for '-server' parameter"
    #endElse
  elif (arg == "-cluster"):
    i = i+1;
    if (i < argc):
      clusterName = sys.argv[i]
    else:
      argerr = "Missing argument for '-cluster' parameter"
    #endElse
  elif (arg == "-templateName"):
    i = i+1;
    if (i < argc):
      templateName = sys.argv[i]
    else:
      argerr = "Missing argument for '-templateName' parameter"
    #endElse
  elif (arg == "-validFrom" or arg == "-validFromUTC"):
    if (arg == "-validFrom"):
      print "WARNING: As of WPS 7.0, parameter '-validFrom' has been deprecated and replaced by '-validFromUTC'."
    i = i+1;
    if (i < argc):
      validFrom = normalizeTimeStamp(sys.argv[i], 0, 0)
      if not validFrom:
        argerr= "Invalid timestamp '" + sys.argv[i] + "', format must be <yyyy>-<MM>-<dd>T<HH>:<mm>:<ss>."
    else:
       argerr = "Missing argument for '-validFromUTC' parameter"
    #endElse
  else:
    argerr = "Invalid command line argument: "+arg
    break
  #endElse
  i += 1
#endWhile

if (argerr == ""):
  if ( (serverName != None) + (clusterName != None) != 1 ):
     argerr = "Exactly one of the '-server' and '-cluster' command line options must be specified"
  elif (templateName == "" or validFrom == ""):
    argerr="Both the '-templateName' and the '-validFromUTC' command line options must be specified"
#endIf

if ( (argerr != "") or (argc==0)  ):
  usage(argerr)
  sys.exit(1)
#endIf

scope = Scope(nodeName = nodeName, serverName = serverName, clusterName = clusterName)

if not scope.isDeploymentTarget():
  usage( str(scope) + " is not a valid deployment target.")
  sys.exit(1)
#endif

if not scope.isBPCDeploymentTarget():
  usage("Process Choreographer is not configured on " + str(scope) + ".")
  sys.exit(1)
#endif

bfmMBeans = scope.lookupMBean("ProcessContainer", 1)
bfmInternalMBean = scope.lookupMBean("InternalProcessContainer", 0)

if not bfmMBeans:
  print str(scope) + " is not available -- make sure the server or at least one cluster member is running."
else:
  signature = ['java.lang.String']
  params = [templateName]
  list = AdminControl.invoke_jmx(ObjectName(bfmInternalMBean), "getInvalidProcessTemplates", params, signature)
  if list:
    found = None
    for template in list:
      if template[2] == validFrom :
        found = template
        print "Removing invalid process template " + templateName + ", valid from " + validFrom + "..."
        for bfmMBean in bfmMBeans:
          AdminControl.invoke(bfmMBean, "deleteInvalidProcessTemplate", [ templateName, validFrom ] )
        #endfor
        print "Done."
        break
      #endif
    #endfor
    if not found:
      print "Could not find invalid process template with matching validFrom " + validFrom + "."
    #endif
  else:
    print "Could not find invalid process template " + templateName + "."
  #endElse
#endElse
